Compute

Enum Compute 

pub enum Compute {
    Compute,
    ComputeEnd,
}
Operations related to VM compute execution.

Variants



Compute

0x90: COM

Hand off execution to compute threads until ComputeEnd operation is encountered. The computes read from a shared memory and write to their local memories, which are reconciled on thread join.

Stack Input

[n_computes]

Stack Output

[compute_index]

Panics
  • Recursion limit (1) is reached.


ComputeEnd

0x91: COME

End of the execution of the compute program.